==> zio-aws-iotwireless_2.13-5.17.121.3-sources.jar: zio/aws/iotwireless/model/GetMulticastGroupSessionResponse.scala <==
package zio.aws.iotwireless.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class GetMulticastGroupSessionResponse(
    loRaWAN: Option[zio.aws.iotwireless.model.LoRaWANMulticastSession] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.iotwireless.model.GetMulticastGroupSessionResponse = {
    import GetMulticastGroupSessionResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.iotwireless.model.GetMulticastGroupSessionResponse
      .builder()
      .optionallyWith(loRaWAN.map(value => value.buildAwsValue()))(_.loRaWAN)
      .build()
  }
  def asReadOnly
      : zio.aws.iotwireless.model.GetMulticastGroupSessionResponse.ReadOnly =
    zio.aws.iotwireless.model.GetMulticastGroupSessionResponse
      .wrap(buildAwsValue())
}
object GetMulticastGroupSessionResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.iotwireless.model.GetMulticastGroupSessionResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.iotwireless.model.GetMulticastGroupSessionResponse =
      zio.aws.iotwireless.model.GetMulticastGroupSessionResponse(
        loRaWAN.map(value => value.asEditable)
      )
    def loRaWAN
        : Option[zio.aws.iotwireless.model.LoRaWANMulticastSession.ReadOnly]
    def getLoRaWAN: ZIO[
      Any,
      AwsError,
      zio.aws.iotwireless.model.LoRaWANMulticastSession.ReadOnly
    ] = AwsError.unwrapOptionField("loRaWAN", loRaWAN)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.iotwireless.model.GetMulticastGroupSessionResponse
  ) extends zio.aws.iotwireless.model.GetMulticastGroupSessionResponse.ReadOnly {
    override val loRaWAN
        : Option[zio.aws.iotwireless.model.LoRaWANMulticastSession.ReadOnly] =
      scala
        .Option(impl.loRaWAN())
        .map(value =>
          zio.aws.iotwireless.model.LoRaWANMulticastSession.wrap(value)
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.iotwireless.model.GetMulticastGroupSessionResponse
  ): zio.aws.iotwireless.model.GetMulticastGroupSessionResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-iotwireless_2.13-7.21.15.12-sources.jar: zio/aws/iotwireless/model/GetMulticastGroupSessionResponse.scala <==
package zio.aws.iotwireless.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class GetMulticastGroupSessionResponse(
    loRaWAN: Optional[zio.aws.iotwireless.model.LoRaWANMulticastSession] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.iotwireless.model.GetMulticastGroupSessionResponse = {
    import GetMulticastGroupSessionResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.iotwireless.model.GetMulticastGroupSessionResponse
      .builder()
      .optionallyWith(loRaWAN.map(value => value.buildAwsValue()))(_.loRaWAN)
      .build()
  }
  def asReadOnly
      : zio.aws.iotwireless.model.GetMulticastGroupSessionResponse.ReadOnly =
    zio.aws.iotwireless.model.GetMulticastGroupSessionResponse
      .wrap(buildAwsValue())
}
object GetMulticastGroupSessionResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.iotwireless.model.GetMulticastGroupSessionResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.iotwireless.model.GetMulticastGroupSessionResponse =
      zio.aws.iotwireless.model.GetMulticastGroupSessionResponse(
        loRaWAN.map(value => value.asEditable)
      )
    def loRaWAN
        : Optional[zio.aws.iotwireless.model.LoRaWANMulticastSession.ReadOnly]
    def getLoRaWAN: ZIO[
      Any,
      AwsError,
      zio.aws.iotwireless.model.LoRaWANMulticastSession.ReadOnly
    ] = AwsError.unwrapOptionField("loRaWAN", loRaWAN)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.iotwireless.model.GetMulticastGroupSessionResponse
  ) extends zio.aws.iotwireless.model.GetMulticastGroupSessionResponse.ReadOnly {
    override val loRaWAN
        : Optional[zio.aws.iotwireless.model.LoRaWANMulticastSession.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.loRaWAN())
        .map(value =>
          zio.aws.iotwireless.model.LoRaWANMulticastSession.wrap(value)
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.iotwireless.model.GetMulticastGroupSessionResponse
  ): zio.aws.iotwireless.model.GetMulticastGroupSessionResponse.ReadOnly =
    new Wrapper(impl)
}
